@@ -1,4 +1,4 @@
-from os import environ
+from os import environ, path
 import warnings
 from typing import Optional, Tuple, List
 from enum import Enum, unique
@@ -11,6 +11,7 @@ from emmet.core.mpid import MPID
 from emmet.core.symmetry import CrystalSystem
 
 from mp_api.core.client import BaseRester
+from mp_api.routes.electronic_structure.models.core import BSPathType
 from mp_api.routes import *
 
 _DEPRECATION_WARNING = (
@@ -106,27 +107,18 @@ class MPRester:
                 self, cls.suffix.replace("/", "_"), rester,
             )
 
-        self.find_structure = self.materials.find_structure
-
-        self.get_bandstructure_by_material_id = (
-            self.electronic_structure_bandstructure.get_bandstructure_from_material_id
-        )
-        self.get_dos_by_material_id = (
-            self.electronic_structure_dos.get_dos_from_material_id
-        )
-
         self.get_charge_density_from_calculation_id = (
             self.charge_density.get_charge_density_from_calculation_id
         )
 
-        self.get_charge_density_calculation_details = (
-            self.charge_density.get_charge_density_calculation_details
-        )
-
         self.get_charge_density_calculation_ids_from_material_id = (
             self.charge_density.get_charge_density_calculation_ids_from_material_id
         )
 
+        self.get_charge_density_calculation_details = (
+            self.charge_density.get_charge_density_calculation_details
+        )
+
     def __enter__(self):
         """
         Support for "with" context.
@@ -229,7 +221,7 @@ class MPRester:
         Returns:
             BibTeX (str)
         """
-        raise NotImplementedError
+        return self.provenance.get_document_by_id(material_id).references
 
     def get_materials_ids(self, chemsys_formula):
         """
@@ -287,6 +279,32 @@ class MPRester:
 
             return structures
 
+    def find_structure(
+        self, filename_or_structure, ltol=0.2, stol=0.3, angle_tol=5, limit=1
+    ):
+        """
+        Finds matching structures on the Materials Project site.
+        Args:
+            filename_or_structure: filename or Structure object
+            ltol: fractional length tolerance
+            stol: site tolerance
+            angle_tol: angle tolerance in degrees
+            limit: amount of structure matches to limit to
+        Returns:
+            A list of matching materials project ids for structure, \
+                including normalized rms distances and max distances between paired sites.
+        Raises:
+            MPRestError
+        """
+
+        return self.materials.find_structure(
+            filename_or_structure,
+            ltol=ltol,
+            stol=stol,
+            angle_tol=angle_tol,
+            limit=limit,
+        )
+
     def get_entries(
         self, chemsys_formula, sort_by_e_above_hull=False,
     ):
@@ -343,6 +361,41 @@ class MPRester:
             ).entries.values()
         )
 
+    def get_bandstructure_by_material_id(
+        self,
+        material_id: str,
+        path_type: BSPathType = BSPathType.setyawan_curtarolo,
+        line_mode=True,
+    ):
+        """
+        Get the band structure pymatgen object associated with a Materials Project ID.
+
+        Arguments:
+            materials_id (str): Materials Project ID for a material
+            path_type (BSPathType): k-point path selection convention
+            line_mode (bool): Whether to return data for a line-mode calculation
+
+        Returns:
+            bandstructure (Union[BandStructure, BandStructureSymmLine]): BandStructure or BandStructureSymmLine object
+        """
+        return self.electronic_structure_bandstructure.get_bandstructure_from_material_id(  # type: ignore
+            material_id=material_id, path_type=path_type, line_mode=line_mode
+        )
+
+    def get_dos_by_material_id(self, material_id: str):
+        """
+        Get the complete density of states pymatgen object associated with a Materials Project ID.
+
+        Arguments:
+            materials_id (str): Materials Project ID for a material
+
+        Returns:
+            dos (CompleteDos): CompleteDos object
+        """
+        return self.electronic_structure_dos.get_dos_from_material_id(  # type: ignore
+            material_id=material_id
+        )
+
     def get_phonon_dos_by_material_id(self, material_id):
         """
         Get phonon density of states data corresponding to a material_id.
@@ -354,7 +407,7 @@ class MPRester:
              CompletePhononDos: A phonon DOS object.
 
         """
-        raise NotImplementedError
+        return self.phonon.get_document_by_id(material_id, fields=["ph_dos"]).ph_dos
 
     def get_phonon_bandstructure_by_material_id(self, material_id):
         """
@@ -366,9 +419,20 @@ class MPRester:
         Returns:
             PhononBandStructureSymmLine:  phonon band structure.
         """
-        doc = self.phonon.get_document_by_id(material_id)
+        return self.phonon.get_document_by_id(material_id, fields=["ph_bs"]).ph_bs
 
-        return doc.ph_bs
+    def get_charge_density_by_material_id(self, material_id: str):
+        """
+        Get charge density data for a given Materials Project ID.
+
+        Arguments:
+            material_id (str): Material Project ID
+
+        Returns:
+            chgcar (dict): Pymatgen CHGCAR object.
+        """
+
+        return self.charge_density.get_charge_density_from_material_id(material_id)  # type: ignore
 
     def query(
         self,
@@ -397,6 +461,8 @@ class MPRester:
         total_magnetization_normalized_formula_units: Optional[
             Tuple[float, float]
         ] = None,
+        num_magnetic_sites: Optional[Tuple[int, int]] = None,
+        num_unique_magnetic_sites: Optional[Tuple[int, int]] = None,
         k_voigt: Optional[Tuple[float, float]] = None,
         k_reuss: Optional[Tuple[float, float]] = None,
         k_vrh: Optional[Tuple[float, float]] = None,
@@ -407,13 +473,14 @@ class MPRester:
         poisson_ratio: Optional[Tuple[float, float]] = None,
         e_total: Optional[Tuple[float, float]] = None,
         e_ionic: Optional[Tuple[float, float]] = None,
-        e_static: Optional[Tuple[float, float]] = None,
+        e_electronic: Optional[Tuple[float, float]] = None,
         n: Optional[Tuple[float, float]] = None,
         piezoelectric_modulus: Optional[Tuple[float, float]] = None,
         weighted_surface_energy: Optional[Tuple[float, float]] = None,
         weighted_work_function: Optional[Tuple[float, float]] = None,
-        surface_anisotropy: Optional[Tuple[float, float]] = None,
+        surface_energy_anisotropy: Optional[Tuple[float, float]] = None,
         shape_factor: Optional[Tuple[float, float]] = None,
+        has_reconstructed: Optional[bool] = None,
         has_props: Optional[List[str]] = None,
         theoretical: Optional[bool] = None,
         sort_field: Optional[str] = None,
@@ -452,6 +519,9 @@ class MPRester:
                 normalized by volume to consider.
             total_magnetization_normalized_formula_units (Tuple[float,float]): Minimum and maximum total magnetization
                 values normalized by formula units to consider.
+            num_magnetic_sites (Tuple[int,int]): Minimum and maximum number of magnetic sites to consider.
+            num_unique_magnetic_sites (Tuple[int,int]): Minimum and maximum number of unique magnetic sites
+                to consider.
             k_voigt (Tuple[float,float]): Minimum and maximum value in GPa to consider for
                 the Voigt average of the bulk modulus.
             k_reuss (Tuple[float,float]): Minimum and maximum value in GPa to consider for
@@ -470,7 +540,7 @@ class MPRester:
                 Poisson's ratio.
             e_total (Tuple[float,float]): Minimum and maximum total dielectric constant to consider.
             e_ionic (Tuple[float,float]): Minimum and maximum ionic dielectric constant to consider.
-            e_static (Tuple[float,float]): Minimum and maximum electronic dielectric constant to consider.
+            e_electronic (Tuple[float,float]): Minimum and maximum electronic dielectric constant to consider.
             n (Tuple[float,float]): Minimum and maximum refractive index to consider.
             piezoelectric_modulus (Tuple[float,float]): Minimum and maximum piezoelectric modulus to consider.
             weighted_surface_energy (Tuple[float,float]): Minimum and maximum weighted surface energy in J/m² to
@@ -479,6 +549,7 @@ class MPRester:
             surface_energy_anisotropy (Tuple[float,float]): Minimum and maximum surface energy anisotropy values to
                 consider.
             shape_factor (Tuple[float,float]): Minimum and maximum shape factor values to consider.
+            has_reconstructed (bool): Whether the entry has any reconstructed surfaces.
             has_props: (List[str]): The calculated properties available for the material.
             theoretical: (bool): Whether the material is theoretical.
             sort_field (str): Field used to sort results.
@@ -490,9 +561,10 @@ class MPRester:
                 Default is material_id if all_fields is False.
 
         Returns:
-            ([SearchDoc]) List of SearchDoc documents
+            ([SummaryDoc]) List of SummaryDoc documents
         """
-        return self.search.search_docs(  # type: ignore
+
+        return self.summary.search_summary_docs(  # type: ignore
             material_ids=material_ids,
             chemsys_formula=chemsys_formula,
             nsites=nsites,
@@ -516,6 +588,8 @@ class MPRester:
             total_magnetization=total_magnetization,
             total_magnetization_normalized_vol=total_magnetization_normalized_vol,
             total_magnetization_normalized_formula_units=total_magnetization_normalized_formula_units,
+            num_magnetic_sites=num_magnetic_sites,
+            num_unique_magnetic_sites=num_unique_magnetic_sites,
             k_voigt=k_voigt,
             k_reuss=k_reuss,
             k_vrh=k_vrh,
@@ -526,13 +600,14 @@ class MPRester:
             poisson_ratio=poisson_ratio,
             e_total=e_total,
             e_ionic=e_ionic,
-            e_static=e_static,
+            e_electronic=e_electronic,
             n=n,
             piezoelectric_modulus=piezoelectric_modulus,
             weighted_surface_energy=weighted_surface_energy,
             weighted_work_function=weighted_work_function,
-            surface_anisotropy=surface_anisotropy,
+            surface_energy_anisotropy=surface_energy_anisotropy,
             shape_factor=shape_factor,
+            has_reconstructed=has_reconstructed,
             has_props=has_props,
             theoretical=theoretical,
             sort_field=sort_field,
@@ -559,39 +634,6 @@ class MPRester:
         # TODO: call new MPComplete endpoint
         raise NotImplementedError
 
-    def get_stability(self, entries):
-        """
-        Returns the stability of all entries.
-        """
-        # TODO: discuss
-        raise NotImplementedError
-
-    def get_cohesive_energy(self, material_id, per_atom=False):
-        """
-        Gets the cohesive for a material (eV per formula unit). Cohesive energy
-            is defined as the difference between the bulk energy and the sum of
-            total DFT energy of isolated atoms for atom elements in the bulk.
-        Args:
-            material_id (str): Materials Project material_id, e.g. 'mp-123'.
-            per_atom (bool): Whether or not to return cohesive energy per atom
-        Returns:
-            Cohesive energy (eV).
-        """
-        raise NotImplementedError
-
-    def get_reaction(self, reactants, products):
-        """
-        Gets a reaction from the Materials Project.
-
-        Args:
-            reactants ([str]): List of formulas
-            products ([str]): List of formulas
-
-        Returns:
-            rxn
-        """
-        raise NotImplementedError
-
     def get_substrates(self, material_id, orient=None):
         """
         Get a substrate list for a material id. The list is in order of
@@ -720,39 +762,3 @@ class MPRester:
                 rotation_axis=rotation_axis,
             )
         ]
-
-    def get_interface_reactions(
-        self,
-        reactant1,
-        reactant2,
-        open_el=None,
-        relative_mu=None,
-        use_hull_energy=False,
-    ):
-        """
-        Gets critical reactions between two reactants.
-
-        Get critical reactions ("kinks" in the mixing ratio where
-        reaction products change) between two reactants. See the
-        `pymatgen.analysis.interface_reactions` module for more info.
-
-        Args:
-            reactant1 (str): Chemical formula for reactant
-            reactant2 (str): Chemical formula for reactant
-            open_el (str): Element in reservoir available to system
-            relative_mu (float): Relative chemical potential of element in
-                reservoir with respect to pure substance. Must be non-positive.
-            use_hull_energy (bool): Whether to use the convex hull energy for a
-            given composition for the reaction energy calculation. If false,
-            the energy of the ground state structure will be preferred; if a
-            ground state can not be found for a composition, the convex hull
-            energy will be used with a warning message.
-
-        Returns:
-            list: list of dicts of form {ratio,energy,rxn} where `ratio` is the
-                reactant mixing ratio, `energy` is the reaction energy
-                in eV/atom, and `rxn` is a
-                `pymatgen.analysis.reaction_calculator.Reaction`.
-
-        """
-        raise NotImplementedError
