@@ -16,14 +16,11 @@ from pymatgen.electronic_structure.dos import CompleteDos
 from pymatgen.entries.computed_entries import ComputedEntry
 from pymatgen.core.periodic_table import Element
 from pymatgen.phonon.bandstructure import PhononBandStructureSymmLine
+from pymatgen.phonon.dos import PhononDos
 from pymatgen.io.vasp import Incar, Chgcar
 from pymatgen.analysis.magnetism import Ordering
 from pymatgen.analysis.wulff import WulffShape
 
-api_is_up = (
-    requests.get("https://api.materialsproject.org/heartbeat").status_code == 200
-)
-
 
 @pytest.fixture()
 def mpr():
@@ -33,8 +30,7 @@ def mpr():
 
 
 @pytest.mark.skipif(
-    ((os.environ.get("MP_API_KEY", None) is None) or (not api_is_up)),
-    reason="API is down",
+    os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
 )
 class TestMPRester:
     def test_get_structure_by_material_id(self, mpr):
@@ -58,10 +54,10 @@ class TestMPRester:
     def test_get_materials_id_from_task_id(self, mpr):
         assert mpr.get_materials_id_from_task_id("mp-540081") == "mp-19017"
 
-    # TODO: add method to MPRester
-    # def test_get_materials_id_references(self, mpr):
-    #     data = mpr.get_materials_id_references("mp-123")
-    #     assert len(data) > 1000
+    @pytest.mark.xfail
+    def test_get_materials_id_references(self, mpr):
+        data = mpr.get_materials_id_references("mp-123")
+        assert len(data) > 5
 
     def test_get_materials_ids_doc(self, mpr):
         mpids = mpr.get_materials_ids("Al2O3")
@@ -116,9 +112,12 @@ class TestMPRester:
         assert sorted_entries != entries
 
     def test_get_phonon_data_by_material_id(self, mpr):
-        bs = mpr.get_phonon_bandstructure_by_material_id("mp-661")
+        bs = mpr.get_phonon_bandstructure_by_material_id("mp-11659")
         assert isinstance(bs, PhononBandStructureSymmLine)
 
+        dos = mpr.get_phonon_dos_by_material_id("mp-11659")
+        assert isinstance(dos, PhononDos)
+
     def test_get_charge_density_data(self, mpr):
         task_ids = mpr.get_charge_density_calculation_ids_from_material_id("mp-149")
         assert len(task_ids) > 0
@@ -131,6 +130,9 @@ class TestMPRester:
         chgcar = mpr.get_charge_density_from_calculation_id(task_ids[0]["task_id"])
         assert isinstance(chgcar, Chgcar)
 
+        chgcar = mpr.get_charge_density_by_material_id("mp-149")
+        assert isinstance(chgcar, Chgcar)
+
     def test_get_substrates(self, mpr):
         substrate_data = mpr.get_substrates("mp-123", [1, 0, 0])
         substrates = [sub_dict["sub_id"] for sub_dict in substrate_data]
@@ -150,7 +152,6 @@ class TestMPRester:
         assert "is_reconstructed" in surface
         assert "structure" in surface
 
-    @pytest.mark.xfail  # temporary
     def test_get_gb_data(self, mpr):
         mo_gbs = mpr.get_gb_data(chemsys="Mo")
         assert len(mo_gbs) == 10
@@ -179,11 +180,6 @@ class TestMPRester:
             "num_chunks",
             "all_fields",
             "fields",
-            "equillibrium_reaction_energy",  # Fix (thermo model)
-            "weighted_work_function",  # Fix (search builder)
-            "weighted_surface_energy",  # Fix (search builder)
-            "surface_anisotropy",  # Fix (search builder)
-            "shape_factor",  # Fix (search builder)
         ]
 
         alt_name_dict = {
@@ -196,10 +192,12 @@ class TestMPRester:
             "total_energy": "energy_per_atom",
             "formation_energy": "formation_energy_per_atom",
             "uncorrected_energy": "uncorrected_energy_per_atom",
+            "equillibrium_reaction_energy": "equillibrium_reaction_energy_per_atom",
             "magnetic_ordering": "ordering",
             "elastic_anisotropy": "universal_anisotropy",
             "poisson_ratio": "homogeneous_poisson",
             "piezoelectric_modulus": "e_ij_max",
+            "surface_energy_anisotropy": "surface_anisotropy",
         }  # type: dict
 
         custom_field_tests = {
@@ -211,6 +209,7 @@ class TestMPRester:
             "magnetic_ordering": Ordering.FM,
             "has_props": ["dielectric"],
             "theoretical": True,
+            "has_reconstructed": False,
         }  # type: dict
 
         search_method = mpr.query
